@@ -1,5 +1,6 @@
-ajusPlot <- function(V, tolerance=0.1, variant="modified") {
+ajusPlot <- function(V, tolerance=0.1, variant="modified", ...) {
 # plot AJUS with additional information
+# additional arguments can now be passed on (e.g col="red", lwd=2)
 # removing NA to deal with real-life data
 # (e.g. time series with missing data)
 a <- ajus(na.omit(V), tolerance=tolerance, variant=variant) # do not consider missing values
@@ -9,8 +10,8 @@ i <- min(V, na.rm=TRUE) # for difference d
 d <- m - i              # for plotting
 #plot(V, type="b", axes=FALSE, xlab="", ylab="")
 miss <- !is.na(V)   # for which years do data exist?
-plot(which(miss), na.omit(V), type="b", axes=FALSE, xlab="", ylab="", xlim=c(1,l)) # plot where data exist
-axis(1, at=1:l)	# control axes
+plot(which(miss), na.omit(V), type="b", axes=FALSE, xlab="", ylab="", xlim=c(1,l), ...) # plot where data exist
+axis(1, at=1:l) # control axes
 axis(2)
 if (m==0) m <- 1 # avoid plotting type on line if "F" at 0
 if (d==0) d <- m # avoit plotting type on line if "F"
